FrameworkEval

Trait FrameworkEval 

pub trait FrameworkEval {
    // Required methods
    fn log_size(&self) -> u32;
    fn max_constraint_log_degree_bound(&self) -> u32;
    fn evaluate<E: EvalAtRow>(&self, eval: E) -> E;
}
A component defined solely in means of the constraints framework.

Implementing this trait introduces implementations for Component and ComponentProver for the SIMD backend. Note that the constraint framework only supports components with columns of the same size.

Required Methods

fn log_size(&self) -> u32

fn max_constraint_log_degree_bound(&self) -> u32

fn evaluate<E: EvalAtRow>(&self, eval: E) -> E

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors