pub struct LogupAtRow<E: EvalAtRow> {
pub interaction: usize,
pub cumsum_shift: SecureField,
pub fracs: Vec<Fraction<E::EF, E::EF>>,
pub is_finalized: bool,
pub log_size: u32,
}Expand description
Evaluates constraints for batched logups. These constraint enforce the sum of multiplicity_i / (z + sum_j alpha^j * x_j) = claimed_sum.
Fields
interaction: usizeThe index of the interaction used for the cumulative sum columns.
cumsum_shift: SecureFieldThe total sum of all the fractions divided by n_rows.
fracs: Vec<Fraction<E::EF, E::EF>>The evaluation of the last cumulative sum column.
is_finalized: boollog_size: u32Implementations