pub struct InfoEvaluator {
pub mask_offsets: TreeVec<Vec<Vec<isize>>>,
pub n_constraints: usize,
pub preprocessed_columns: Vec<PreProcessedColumnId>,
pub logup: LogupAtRow<Self>,
pub arithmetic_counts: ArithmeticCounts,
pub logup_counts: LogupCountPerRow,
}Expand description
Collects information about the constraints. This includes mask offsets and columns at each interaction, the number of constraints and number of arithmetic operations.
Fields
mask_offsets: TreeVec<Vec<Vec<isize>>>n_constraints: usizepreprocessed_columns: Vec<PreProcessedColumnId>logup: LogupAtRow<Self>arithmetic_counts: ArithmeticCountslogup_counts: LogupCountPerRowImplementations
Sourceimpl InfoEvaluator
impl InfoEvaluator
pub fn new( log_size: u32, preprocessed_columns: Vec<PreProcessedColumnId>, claimed_sum: SecureField, ) -> Self